parts = {
    "rpi-camera": "",
    "ultrasonic-sensor": "4 x",
    "nuts-bolts-spacers": " + ".join(
        [
            "M2: ({})".format(
                " + ".join(
                    [
                        "2 x bolt",
                        "4 x nut",
                        "2 x 5 mm spacer",
                    ]
                )
            ),
            "M3: ({})".format(
                " + ".join(
                    [
                        "4 x 15 mm spacer",
                    ]
                )
            ),
        ]
    ),
    "dupont-cables": "1 x 30 cm + 1 x 10 cm",
    "strong-thread": "1 m",
}
